Crate machi_tools

Crate machi_tools 

Tool contracts, streaming protocol, and concurrent dispatch for Machi.

Maturity: core.

Re-exports

pub use approval::AlwaysDeny;
pub use approval::ApprovalDecision;
pub use approval::ApprovalGate;
pub use approval::AutoApprove;
pub use approval::denied_error;
pub use calc::CalcTool;
pub use context::EXTRA_SPAWN_DEPTH;
pub use context::ToolCallContext;
pub use dispatch::ApprovalPolicy;
pub use dispatch::DispatchOutcome;
pub use dispatch::DispatchRequest;
pub use dispatch::ToolDispatch;
pub use error::ToolError;
pub use metadata::CapabilityFlag;
pub use metadata::ConcurrencyMode;
pub use metadata::Destructiveness;
pub use metadata::InterruptBehavior;
pub use metadata::ToolMetadata;
pub use registry::CapabilityMode;
pub use registry::ToolRegistry;
pub use source::StaticToolSource;
pub use source::ToolSource;
pub use source::merge_arc_sources;
pub use source::merge_tool_sources;
pub use stream::MAX_DELTA_BYTES;
pub use stream::MAX_FRAME_BYTES;
pub use stream::ToolProgress;
pub use stream::ToolStream;
pub use stream::ToolStreamItem;
pub use stream::drain_terminal;
pub use stream::drain_with_progress;
pub use stream::partial_progress_frames;
pub use stream::terminal_only;
pub use stream::with_progress;
pub use tool::DynTool;
pub use tool::SharedTool;
pub use tool::ToolDefinition;
pub use tool::ToolResult;

Modules

approval
Approval gate for destructive or privileged tool calls.
calc
Simple arithmetic evaluation tool for demos and tests.
context
Per-call execution context.
dispatch
Concurrent tool dispatch with exclusivity, capability, and approval gates.
error
Tool-domain errors.
metadata
Tool behavioral metadata and capability flags.
registry
Tool registry with capability filtering.
source
Tool sources: static lists and merge for multi-origin tool sets.
stream
Streaming tool execution protocol.
tool
Tool definition and dynamic execution surface.